@@ -1,16 +1,16 @@
-#!/usr/bin/env python
-#
-# This code is part of the binding affinity prediction tools distribution
-# and governed by its license.  Please see the LICENSE file that should
-# have been included as part of this package.
-#
-
 """
 Models to predict binding affinity based on molecular properties.
 """
 
 
-def IC_NIS(ic_cc, ic_ca, ic_pp, ic_pa, p_nis_a, p_nis_c):
+def IC_NIS(
+    ic_cc: float,
+    ic_ca: float,
+    ic_pp: float,
+    ic_pa: float,
+    p_nis_a: float,
+    p_nis_c: float,
+) -> float:
     """
     Calculates the predicted binding affinity value
     based on the IC-NIS model.
@@ -27,7 +27,7 @@ def IC_NIS(ic_cc, ic_ca, ic_pp, ic_pa, p_nis_a, p_nis_c):
     )
 
 
-def NIS(p_nis_c, p_nis_p, n_int_atoms):
+def NIS(p_nis_c: float, p_nis_p: float, n_int_atoms: float) -> float:
     """
     Calculates the predicted binding affinity value
     based on the NIS model.
